
#ifndef _C1_kl28_
#define _C1_kl28_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F32_368(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern EIF_BOOLEAN F32_369(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit28(void);

#ifdef __cplusplus
}
#endif

#endif
